@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class DrsVmOverride(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-vsphere.drsVmOverride.DrsVmOverride",
 ):
@@ -30,21 +30,21 @@ class DrsVmOverride(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         compute_cluster_id: builtins.str,
         virtual_machine_id: builtins.str,
         drs_automation_level: typing.Optional[builtins.str] = None,
-        drs_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        drs_enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/vsphere/r/drs_vm_override vsphere_drs_vm_override} Resource.
 
@@ -64,25 +64,7 @@ class DrsVmOverride(
         :param provisioners: 
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id_: builtins.str,
-                *,
-                compute_cluster_id: builtins.str,
-                virtual_machine_id: builtins.str,
-                drs_automation_level: typing.Optional[builtins.str] = None,
-                drs_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                id: typing.Optional[builtins.str] = None,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0dee0e6d2f7ca832afb526d048d7dc3c5a97e3a23941db2fbe10835266536d70)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DrsVmOverrideConfig(
@@ -137,8 +119,8 @@ class DrsVmOverride(
     @jsii.member(jsii_name="drsEnabledInput")
     def drs_enabled_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "drsEnabledInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "drsEnabledInput"))
 
     @builtins.property
     @jsii.member(jsii_name="idInput")
@@ -158,9 +140,7 @@ class DrsVmOverride(
     @compute_cluster_id.setter
     def compute_cluster_id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8029229fb9ac85c9ad5fae7b5c38405e18a17d7f284d151508d458b88affd7c2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "computeClusterId", value)
 
@@ -172,26 +152,22 @@ class DrsVmOverride(
     @drs_automation_level.setter
     def drs_automation_level(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7938eeeda0dd3df36a67bcf637aa45fdb05d4a3176cbee8ce12ede7976efd26a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "drsAutomationLevel", value)
 
     @builtins.property
     @jsii.member(jsii_name="drsEnabled")
-    def drs_enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "drsEnabled"))
+    def drs_enabled(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "drsEnabled"))
 
     @drs_enabled.setter
     def drs_enabled(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__004f82feb0a09c34f7978222f9a09cdc15ae01a83e540406b75fa7f9ecbc06c8)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "drsEnabled", value)
 
@@ -203,9 +179,7 @@ class DrsVmOverride(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d1d7151fea7877dbb064338984fffb6b766ed2199192d74162c6a490199c4a0e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -217,16 +191,14 @@ class DrsVmOverride(
     @virtual_machine_id.setter
     def virtual_machine_id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a03e485c7bfdcf6a79fa7ab626e31e7d31e2b8a8c8fb945a6de64d72d1254ec0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "virtualMachineId", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-vsphere.drsVmOverride.DrsVmOverrideConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -242,21 +214,21 @@ class DrsVmOverride(
         "id": "id",
     },
 )
-class DrsVmOverrideConfig(cdktf.TerraformMetaArguments):
+class DrsVmOverrideConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         compute_cluster_id: builtins.str,
         virtual_machine_id: builtins.str,
         drs_automation_level: typing.Optional[builtins.str] = None,
-        drs_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        drs_enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -274,25 +246,9 @@ class DrsVmOverrideConfig(cdktf.TerraformMetaArguments):
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/drs_vm_override#id DrsVmOverride#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            def stub(
-                *,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-                compute_cluster_id: builtins.str,
-                virtual_machine_id: builtins.str,
-                drs_automation_level: typing.Optional[builtins.str] = None,
-                drs_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                id: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__889df728b4ea14b721730210a8f1fda0dd7245d8ecc983c35567df6638f608de)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -305,7 +261,7 @@ class DrsVmOverrideConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument drs_automation_level", value=drs_automation_level, expected_type=type_hints["drs_automation_level"])
             check_type(argname="argument drs_enabled", value=drs_enabled, expected_type=type_hints["drs_enabled"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "compute_cluster_id": compute_cluster_id,
             "virtual_machine_id": virtual_machine_id,
         }
@@ -333,12 +289,12 @@ class DrsVmOverrideConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -349,46 +305,48 @@ class DrsVmOverrideConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def compute_cluster_id(self) -> builtins.str:
@@ -422,13 +380,13 @@ class DrsVmOverrideConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def drs_enabled(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Enable DRS for this virtual machine.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/drs_vm_override#drs_enabled DrsVmOverride#drs_enabled}
         '''
         result = self._values.get("drs_enabled")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
@@ -458,3 +416,71 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__0dee0e6d2f7ca832afb526d048d7dc3c5a97e3a23941db2fbe10835266536d70(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    compute_cluster_id: builtins.str,
+    virtual_machine_id: builtins.str,
+    drs_automation_level: typing.Optional[builtins.str] = None,
+    drs_enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8029229fb9ac85c9ad5fae7b5c38405e18a17d7f284d151508d458b88affd7c2(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7938eeeda0dd3df36a67bcf637aa45fdb05d4a3176cbee8ce12ede7976efd26a(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__004f82feb0a09c34f7978222f9a09cdc15ae01a83e540406b75fa7f9ecbc06c8(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d1d7151fea7877dbb064338984fffb6b766ed2199192d74162c6a490199c4a0e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a03e485c7bfdcf6a79fa7ab626e31e7d31e2b8a8c8fb945a6de64d72d1254ec0(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__889df728b4ea14b721730210a8f1fda0dd7245d8ecc983c35567df6638f608de(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    compute_cluster_id: builtins.str,
+    virtual_machine_id: builtins.str,
+    drs_automation_level: typing.Optional[builtins.str] = None,
+    drs_enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
