@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class HaVmOverride(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-vsphere.haVmOverride.HaVmOverride",
 ):
@@ -30,7 +30,7 @@ class HaVmOverride(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         compute_cluster_id: builtins.str,
@@ -45,17 +45,17 @@ class HaVmOverride(
         ha_vm_maximum_resets: typing.Optional[jsii.Number] = None,
         ha_vm_minimum_uptime: typing.Optional[jsii.Number] = None,
         ha_vm_monitoring: typing.Optional[builtins.str] = None,
-        ha_vm_monitoring_use_cluster_defaults: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        ha_vm_monitoring_use_cluster_defaults: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         ha_vm_restart_priority: typing.Optional[builtins.str] = None,
         ha_vm_restart_timeout: typing.Optional[jsii.Number] = None,
         id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/vsphere/r/ha_vm_override vsphere_ha_vm_override} Resource.
 
@@ -86,36 +86,7 @@ class HaVmOverride(
         :param provisioners: 
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id_: builtins.str,
-                *,
-                compute_cluster_id: builtins.str,
-                virtual_machine_id: builtins.str,
-                ha_datastore_apd_recovery_action: typing.Optional[builtins.str] = None,
-                ha_datastore_apd_response: typing.Optional[builtins.str] = None,
-                ha_datastore_apd_response_delay: typing.Optional[jsii.Number] = None,
-                ha_datastore_pdl_response: typing.Optional[builtins.str] = None,
-                ha_host_isolation_response: typing.Optional[builtins.str] = None,
-                ha_vm_failure_interval: typing.Optional[jsii.Number] = None,
-                ha_vm_maximum_failure_window: typing.Optional[jsii.Number] = None,
-                ha_vm_maximum_resets: typing.Optional[jsii.Number] = None,
-                ha_vm_minimum_uptime: typing.Optional[jsii.Number] = None,
-                ha_vm_monitoring: typing.Optional[builtins.str] = None,
-                ha_vm_monitoring_use_cluster_defaults: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                ha_vm_restart_priority: typing.Optional[builtins.str] = None,
-                ha_vm_restart_timeout: typing.Optional[jsii.Number] = None,
-                id: typing.Optional[builtins.str] = None,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4a362f73d90dca8d6f75702e2c8edfa896016f62abcf695a0bb12dce218c9b52)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = HaVmOverrideConfig(
@@ -270,8 +241,8 @@ class HaVmOverride(
     @jsii.member(jsii_name="haVmMonitoringUseClusterDefaultsInput")
     def ha_vm_monitoring_use_cluster_defaults_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "haVmMonitoringUseClusterDefaultsInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "haVmMonitoringUseClusterDefaultsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="haVmRestartPriorityInput")
@@ -301,9 +272,7 @@ class HaVmOverride(
     @compute_cluster_id.setter
     def compute_cluster_id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__557177dab0528ece41558a7ac7697cdc548705065084adfce0800056b354f542)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "computeClusterId", value)
 
@@ -315,9 +284,7 @@ class HaVmOverride(
     @ha_datastore_apd_recovery_action.setter
     def ha_datastore_apd_recovery_action(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f256c9f5050cae30a5a4f8f84e0d110d8cb3e7154b5d7ce034f1ddd3a4755dde)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haDatastoreApdRecoveryAction", value)
 
@@ -329,9 +296,7 @@ class HaVmOverride(
     @ha_datastore_apd_response.setter
     def ha_datastore_apd_response(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ea523e6cfa809bc283af2f4d1418635e8b0452b4efe74792eee607e933770039)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haDatastoreApdResponse", value)
 
@@ -343,9 +308,7 @@ class HaVmOverride(
     @ha_datastore_apd_response_delay.setter
     def ha_datastore_apd_response_delay(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3bb6e4e2851b4c7f6f866494f79bd71ac773b9a38038c4e55301d6a52bc44af6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haDatastoreApdResponseDelay", value)
 
@@ -357,9 +320,7 @@ class HaVmOverride(
     @ha_datastore_pdl_response.setter
     def ha_datastore_pdl_response(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e22a9d6bb85c6efc7c2baafccc2b8071147dd5370530bee0151877299c60974e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haDatastorePdlResponse", value)
 
@@ -371,9 +332,7 @@ class HaVmOverride(
     @ha_host_isolation_response.setter
     def ha_host_isolation_response(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__24eba372c4dc3ddc05440c19146b3817dd93055e36990f719a011fa8048bf5dd)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haHostIsolationResponse", value)
 
@@ -385,9 +344,7 @@ class HaVmOverride(
     @ha_vm_failure_interval.setter
     def ha_vm_failure_interval(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a59c2467408e14a5e776a9e38b168395004c9fd9f69bfe0b0748e87709d7f1c7)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmFailureInterval", value)
 
@@ -399,9 +356,7 @@ class HaVmOverride(
     @ha_vm_maximum_failure_window.setter
     def ha_vm_maximum_failure_window(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__eea261c1919e23959fbc771dc8fed0ba219ccaf427929a2aea52452d0257af20)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmMaximumFailureWindow", value)
 
@@ -413,9 +368,7 @@ class HaVmOverride(
     @ha_vm_maximum_resets.setter
     def ha_vm_maximum_resets(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3ba13c4bac5f6d4f97d2d9cf98d2cc9050cce14ac68ccf13fb46528af4b3e189)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmMaximumResets", value)
 
@@ -427,9 +380,7 @@ class HaVmOverride(
     @ha_vm_minimum_uptime.setter
     def ha_vm_minimum_uptime(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5819c3f82d8cd9a9505ec0a3e32598c1033cbf11867093eb9bd1557090a9a126)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmMinimumUptime", value)
 
@@ -441,9 +392,7 @@ class HaVmOverride(
     @ha_vm_monitoring.setter
     def ha_vm_monitoring(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6565e93f8c94253a21c6a9d461bb5ae54dfdf0c875f59e6a6c268a04b54dfdd3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmMonitoring", value)
 
@@ -451,18 +400,16 @@ class HaVmOverride(
     @jsii.member(jsii_name="haVmMonitoringUseClusterDefaults")
     def ha_vm_monitoring_use_cluster_defaults(
         self,
-    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "haVmMonitoringUseClusterDefaults"))
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "haVmMonitoringUseClusterDefaults"))
 
     @ha_vm_monitoring_use_cluster_defaults.setter
     def ha_vm_monitoring_use_cluster_defaults(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4345868e87693c387b7b01181a722805772338361c6ad67afdf1d2eef49c9d67)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmMonitoringUseClusterDefaults", value)
 
@@ -474,9 +421,7 @@ class HaVmOverride(
     @ha_vm_restart_priority.setter
     def ha_vm_restart_priority(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6ab3125195723f9f4b8d007e0cd7be6e953d4e31cd75b5f453a0e7e7764e6638)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmRestartPriority", value)
 
@@ -488,9 +433,7 @@ class HaVmOverride(
     @ha_vm_restart_timeout.setter
     def ha_vm_restart_timeout(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__cd4786a1c82dd41dcc593f0da050522c92f7195bb8a390e5d69cc31976fdb386)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "haVmRestartTimeout", value)
 
@@ -502,9 +445,7 @@ class HaVmOverride(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__502e30cf9cca42e53c488650d96eb7a63bc4d956fb3151070c6f901c2ef636ed)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -516,16 +457,14 @@ class HaVmOverride(
     @virtual_machine_id.setter
     def virtual_machine_id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__915f3a1552773b6d97f4e79c4793bdba2607ceed57f0167a116aebed4b41dc2a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "virtualMachineId", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-vsphere.haVmOverride.HaVmOverrideConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -552,17 +491,17 @@ class HaVmOverride(
         "id": "id",
     },
 )
-class HaVmOverrideConfig(cdktf.TerraformMetaArguments):
+class HaVmOverrideConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         compute_cluster_id: builtins.str,
         virtual_machine_id: builtins.str,
         ha_datastore_apd_recovery_action: typing.Optional[builtins.str] = None,
@@ -575,7 +514,7 @@ class HaVmOverrideConfig(cdktf.TerraformMetaArguments):
         ha_vm_maximum_resets: typing.Optional[jsii.Number] = None,
         ha_vm_minimum_uptime: typing.Optional[jsii.Number] = None,
         ha_vm_monitoring: typing.Optional[builtins.str] = None,
-        ha_vm_monitoring_use_cluster_defaults: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        ha_vm_monitoring_use_cluster_defaults: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         ha_vm_restart_priority: typing.Optional[builtins.str] = None,
         ha_vm_restart_timeout: typing.Optional[jsii.Number] = None,
         id: typing.Optional[builtins.str] = None,
@@ -606,36 +545,9 @@ class HaVmOverrideConfig(cdktf.TerraformMetaArguments):
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/ha_vm_override#id HaVmOverride#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            def stub(
-                *,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-                compute_cluster_id: builtins.str,
-                virtual_machine_id: builtins.str,
-                ha_datastore_apd_recovery_action: typing.Optional[builtins.str] = None,
-                ha_datastore_apd_response: typing.Optional[builtins.str] = None,
-                ha_datastore_apd_response_delay: typing.Optional[jsii.Number] = None,
-                ha_datastore_pdl_response: typing.Optional[builtins.str] = None,
-                ha_host_isolation_response: typing.Optional[builtins.str] = None,
-                ha_vm_failure_interval: typing.Optional[jsii.Number] = None,
-                ha_vm_maximum_failure_window: typing.Optional[jsii.Number] = None,
-                ha_vm_maximum_resets: typing.Optional[jsii.Number] = None,
-                ha_vm_minimum_uptime: typing.Optional[jsii.Number] = None,
-                ha_vm_monitoring: typing.Optional[builtins.str] = None,
-                ha_vm_monitoring_use_cluster_defaults: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                ha_vm_restart_priority: typing.Optional[builtins.str] = None,
-                ha_vm_restart_timeout: typing.Optional[jsii.Number] = None,
-                id: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6e901efdc3423ad9e40b41b2f1f51e91d15a27b4686337b35e9a82d02a3e9143)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -659,7 +571,7 @@ class HaVmOverrideConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument ha_vm_restart_priority", value=ha_vm_restart_priority, expected_type=type_hints["ha_vm_restart_priority"])
             check_type(argname="argument ha_vm_restart_timeout", value=ha_vm_restart_timeout, expected_type=type_hints["ha_vm_restart_timeout"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "compute_cluster_id": compute_cluster_id,
             "virtual_machine_id": virtual_machine_id,
         }
@@ -709,12 +621,12 @@ class HaVmOverrideConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -725,46 +637,48 @@ class HaVmOverrideConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def compute_cluster_id(self) -> builtins.str:
@@ -895,7 +809,7 @@ class HaVmOverrideConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def ha_vm_monitoring_use_cluster_defaults(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Determines whether or not the cluster's default settings or the VM override settings specified in this resource are used for virtual machine monitoring.
 
         The default is true (use cluster defaults) - set to false to have overrides take effect.
@@ -903,7 +817,7 @@ class HaVmOverrideConfig(cdktf.TerraformMetaArguments):
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/ha_vm_override#ha_vm_monitoring_use_cluster_defaults HaVmOverride#ha_vm_monitoring_use_cluster_defaults}
         '''
         result = self._values.get("ha_vm_monitoring_use_cluster_defaults")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def ha_vm_restart_priority(self) -> typing.Optional[builtins.str]:
@@ -955,3 +869,159 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__4a362f73d90dca8d6f75702e2c8edfa896016f62abcf695a0bb12dce218c9b52(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    compute_cluster_id: builtins.str,
+    virtual_machine_id: builtins.str,
+    ha_datastore_apd_recovery_action: typing.Optional[builtins.str] = None,
+    ha_datastore_apd_response: typing.Optional[builtins.str] = None,
+    ha_datastore_apd_response_delay: typing.Optional[jsii.Number] = None,
+    ha_datastore_pdl_response: typing.Optional[builtins.str] = None,
+    ha_host_isolation_response: typing.Optional[builtins.str] = None,
+    ha_vm_failure_interval: typing.Optional[jsii.Number] = None,
+    ha_vm_maximum_failure_window: typing.Optional[jsii.Number] = None,
+    ha_vm_maximum_resets: typing.Optional[jsii.Number] = None,
+    ha_vm_minimum_uptime: typing.Optional[jsii.Number] = None,
+    ha_vm_monitoring: typing.Optional[builtins.str] = None,
+    ha_vm_monitoring_use_cluster_defaults: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    ha_vm_restart_priority: typing.Optional[builtins.str] = None,
+    ha_vm_restart_timeout: typing.Optional[jsii.Number] = None,
+    id: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__557177dab0528ece41558a7ac7697cdc548705065084adfce0800056b354f542(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f256c9f5050cae30a5a4f8f84e0d110d8cb3e7154b5d7ce034f1ddd3a4755dde(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ea523e6cfa809bc283af2f4d1418635e8b0452b4efe74792eee607e933770039(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3bb6e4e2851b4c7f6f866494f79bd71ac773b9a38038c4e55301d6a52bc44af6(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e22a9d6bb85c6efc7c2baafccc2b8071147dd5370530bee0151877299c60974e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__24eba372c4dc3ddc05440c19146b3817dd93055e36990f719a011fa8048bf5dd(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a59c2467408e14a5e776a9e38b168395004c9fd9f69bfe0b0748e87709d7f1c7(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__eea261c1919e23959fbc771dc8fed0ba219ccaf427929a2aea52452d0257af20(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3ba13c4bac5f6d4f97d2d9cf98d2cc9050cce14ac68ccf13fb46528af4b3e189(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5819c3f82d8cd9a9505ec0a3e32598c1033cbf11867093eb9bd1557090a9a126(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6565e93f8c94253a21c6a9d461bb5ae54dfdf0c875f59e6a6c268a04b54dfdd3(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4345868e87693c387b7b01181a722805772338361c6ad67afdf1d2eef49c9d67(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6ab3125195723f9f4b8d007e0cd7be6e953d4e31cd75b5f453a0e7e7764e6638(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cd4786a1c82dd41dcc593f0da050522c92f7195bb8a390e5d69cc31976fdb386(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__502e30cf9cca42e53c488650d96eb7a63bc4d956fb3151070c6f901c2ef636ed(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__915f3a1552773b6d97f4e79c4793bdba2607ceed57f0167a116aebed4b41dc2a(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6e901efdc3423ad9e40b41b2f1f51e91d15a27b4686337b35e9a82d02a3e9143(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    compute_cluster_id: builtins.str,
+    virtual_machine_id: builtins.str,
+    ha_datastore_apd_recovery_action: typing.Optional[builtins.str] = None,
+    ha_datastore_apd_response: typing.Optional[builtins.str] = None,
+    ha_datastore_apd_response_delay: typing.Optional[jsii.Number] = None,
+    ha_datastore_pdl_response: typing.Optional[builtins.str] = None,
+    ha_host_isolation_response: typing.Optional[builtins.str] = None,
+    ha_vm_failure_interval: typing.Optional[jsii.Number] = None,
+    ha_vm_maximum_failure_window: typing.Optional[jsii.Number] = None,
+    ha_vm_maximum_resets: typing.Optional[jsii.Number] = None,
+    ha_vm_minimum_uptime: typing.Optional[jsii.Number] = None,
+    ha_vm_monitoring: typing.Optional[builtins.str] = None,
+    ha_vm_monitoring_use_cluster_defaults: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    ha_vm_restart_priority: typing.Optional[builtins.str] = None,
+    ha_vm_restart_timeout: typing.Optional[jsii.Number] = None,
+    id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
