@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class VsphereProvider(
-    cdktf.TerraformProvider,
+    _cdktf_9a9027ec.TerraformProvider,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-vsphere.provider.VsphereProvider",
 ):
@@ -30,18 +30,18 @@ class VsphereProvider(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         password: builtins.str,
         user: builtins.str,
         alias: typing.Optional[builtins.str] = None,
-        allow_unverified_ssl: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        allow_unverified_ssl: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         api_timeout: typing.Optional[jsii.Number] = None,
-        client_debug: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        client_debug: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         client_debug_path: typing.Optional[builtins.str] = None,
         client_debug_path_run: typing.Optional[builtins.str] = None,
-        persist_session: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        persist_session: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         rest_session_path: typing.Optional[builtins.str] = None,
         vcenter_server: typing.Optional[builtins.str] = None,
         vim_keep_alive: typing.Optional[jsii.Number] = None,
@@ -68,27 +68,7 @@ class VsphereProvider(
         :param vsphere_server: The vSphere Server name for vSphere API operations. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere#vsphere_server VsphereProvider#vsphere_server}
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                password: builtins.str,
-                user: builtins.str,
-                alias: typing.Optional[builtins.str] = None,
-                allow_unverified_ssl: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                api_timeout: typing.Optional[jsii.Number] = None,
-                client_debug: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                client_debug_path: typing.Optional[builtins.str] = None,
-                client_debug_path_run: typing.Optional[builtins.str] = None,
-                persist_session: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                rest_session_path: typing.Optional[builtins.str] = None,
-                vcenter_server: typing.Optional[builtins.str] = None,
-                vim_keep_alive: typing.Optional[jsii.Number] = None,
-                vim_session_path: typing.Optional[builtins.str] = None,
-                vsphere_server: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ee026a52613711b09c00984c1711ee0ea723e1281f3052e2fd4da2b6813e9712)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = VsphereProviderConfig(
@@ -176,8 +156,8 @@ class VsphereProvider(
     @jsii.member(jsii_name="allowUnverifiedSslInput")
     def allow_unverified_ssl_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "allowUnverifiedSslInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "allowUnverifiedSslInput"))
 
     @builtins.property
     @jsii.member(jsii_name="apiTimeoutInput")
@@ -188,8 +168,8 @@ class VsphereProvider(
     @jsii.member(jsii_name="clientDebugInput")
     def client_debug_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "clientDebugInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "clientDebugInput"))
 
     @builtins.property
     @jsii.member(jsii_name="clientDebugPathInput")
@@ -210,8 +190,8 @@ class VsphereProvider(
     @jsii.member(jsii_name="persistSessionInput")
     def persist_session_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "persistSessionInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "persistSessionInput"))
 
     @builtins.property
     @jsii.member(jsii_name="restSessionPathInput")
@@ -251,9 +231,7 @@ class VsphereProvider(
     @alias.setter
     def alias(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__85a5c7404c22e2662c8f2b36e7bac7c3c330755af050b318ea3270269facd5fc)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "alias", value)
 
@@ -261,20 +239,16 @@ class VsphereProvider(
     @jsii.member(jsii_name="allowUnverifiedSsl")
     def allow_unverified_ssl(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "allowUnverifiedSsl"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "allowUnverifiedSsl"))
 
     @allow_unverified_ssl.setter
     def allow_unverified_ssl(
         self,
-        value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__efa987cfc550d9bd2c5835330213c9fcee3a796902fa8c4e5c6a567d25c9382b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "allowUnverifiedSsl", value)
 
@@ -286,9 +260,7 @@ class VsphereProvider(
     @api_timeout.setter
     def api_timeout(self, value: typing.Optional[jsii.Number]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[jsii.Number]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1d49d1962d4c843bdc5b6559e73f4b084c4b70d0d6095e9df5cf25abb428444f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "apiTimeout", value)
 
@@ -296,20 +268,16 @@ class VsphereProvider(
     @jsii.member(jsii_name="clientDebug")
     def client_debug(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "clientDebug"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "clientDebug"))
 
     @client_debug.setter
     def client_debug(
         self,
-        value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7cae6e0d733c5b071ac17da413a7c5bc493ce13b5b796b2c5e8af127cb3ac16e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientDebug", value)
 
@@ -321,9 +289,7 @@ class VsphereProvider(
     @client_debug_path.setter
     def client_debug_path(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1d4a4c3885a74541897f23aaf27d7b316a33faafd025e441e73f82230789dc3b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientDebugPath", value)
 
@@ -335,9 +301,7 @@ class VsphereProvider(
     @client_debug_path_run.setter
     def client_debug_path_run(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__017137ad0dd39052c7f9e0eda5e0706736e5179981fc2763a5440085c8ab25e8)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientDebugPathRun", value)
 
@@ -349,9 +313,7 @@ class VsphereProvider(
     @password.setter
     def password(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c8d6ab5398e3ff1d9b079ef3ac803090a563fc1150bf33ba54693aab2798cdbf)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "password", value)
 
@@ -359,20 +321,16 @@ class VsphereProvider(
     @jsii.member(jsii_name="persistSession")
     def persist_session(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "persistSession"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "persistSession"))
 
     @persist_session.setter
     def persist_session(
         self,
-        value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__24e6a601113c7ec7d0d7ce3b407765402f397b51e33bf7c259d38d98cbb2650d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "persistSession", value)
 
@@ -384,9 +342,7 @@ class VsphereProvider(
     @rest_session_path.setter
     def rest_session_path(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b27f34b61805c00af253b6df02b768883d159c15c46bcc8c546d3a561987131a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "restSessionPath", value)
 
@@ -398,9 +354,7 @@ class VsphereProvider(
     @user.setter
     def user(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d81d54af5728cb1a20ec1fda0589644e0697c48f1c2b8fc5ab341e53d5e19ca4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "user", value)
 
@@ -412,9 +366,7 @@ class VsphereProvider(
     @vcenter_server.setter
     def vcenter_server(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__bbbec703afa84abdf146fa976cc8187d65ff67fd45dc268b875e8372c4b39bf5)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vcenterServer", value)
 
@@ -426,9 +378,7 @@ class VsphereProvider(
     @vim_keep_alive.setter
     def vim_keep_alive(self, value: typing.Optional[jsii.Number]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[jsii.Number]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2f66ec4c1c7d4a23480406c75d8cffe7c94f8b5f9980725dbd57f0b1d2843fd9)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vimKeepAlive", value)
 
@@ -440,9 +390,7 @@ class VsphereProvider(
     @vim_session_path.setter
     def vim_session_path(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__fdf3b73ca434e2bb2e75400348a4f079b7c72997eff4f0cd08ca18625dbb6c73)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vimSessionPath", value)
 
@@ -454,9 +402,7 @@ class VsphereProvider(
     @vsphere_server.setter
     def vsphere_server(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1954f991ead072d7913c4b8fe881f938a0ec15394dc06da3984df4d4af2e8ce9)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "vsphereServer", value)
 
@@ -488,12 +434,12 @@ class VsphereProviderConfig:
         password: builtins.str,
         user: builtins.str,
         alias: typing.Optional[builtins.str] = None,
-        allow_unverified_ssl: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        allow_unverified_ssl: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         api_timeout: typing.Optional[jsii.Number] = None,
-        client_debug: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        client_debug: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         client_debug_path: typing.Optional[builtins.str] = None,
         client_debug_path_run: typing.Optional[builtins.str] = None,
-        persist_session: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        persist_session: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         rest_session_path: typing.Optional[builtins.str] = None,
         vcenter_server: typing.Optional[builtins.str] = None,
         vim_keep_alive: typing.Optional[jsii.Number] = None,
@@ -517,25 +463,7 @@ class VsphereProviderConfig:
         :param vsphere_server: The vSphere Server name for vSphere API operations. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere#vsphere_server VsphereProvider#vsphere_server}
         '''
         if __debug__:
-            def stub(
-                *,
-                password: builtins.str,
-                user: builtins.str,
-                alias: typing.Optional[builtins.str] = None,
-                allow_unverified_ssl: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                api_timeout: typing.Optional[jsii.Number] = None,
-                client_debug: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                client_debug_path: typing.Optional[builtins.str] = None,
-                client_debug_path_run: typing.Optional[builtins.str] = None,
-                persist_session: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                rest_session_path: typing.Optional[builtins.str] = None,
-                vcenter_server: typing.Optional[builtins.str] = None,
-                vim_keep_alive: typing.Optional[jsii.Number] = None,
-                vim_session_path: typing.Optional[builtins.str] = None,
-                vsphere_server: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5b3d3ddbf5e3b8ebcad247b5a75b14c872c731a5a99a03a31d3a90a237b8c26b)
             check_type(argname="argument password", value=password, expected_type=type_hints["password"])
             check_type(argname="argument user", value=user, expected_type=type_hints["user"])
             check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
@@ -550,7 +478,7 @@ class VsphereProviderConfig:
             check_type(argname="argument vim_keep_alive", value=vim_keep_alive, expected_type=type_hints["vim_keep_alive"])
             check_type(argname="argument vim_session_path", value=vim_session_path, expected_type=type_hints["vim_session_path"])
             check_type(argname="argument vsphere_server", value=vsphere_server, expected_type=type_hints["vsphere_server"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "password": password,
             "user": user,
         }
@@ -611,13 +539,13 @@ class VsphereProviderConfig:
     @builtins.property
     def allow_unverified_ssl(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''If set, VMware vSphere client will permit unverifiable SSL certificates.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere#allow_unverified_ssl VsphereProvider#allow_unverified_ssl}
         '''
         result = self._values.get("allow_unverified_ssl")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def api_timeout(self) -> typing.Optional[jsii.Number]:
@@ -631,13 +559,13 @@ class VsphereProviderConfig:
     @builtins.property
     def client_debug(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''govmomi debug.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere#client_debug VsphereProvider#client_debug}
         '''
         result = self._values.get("client_debug")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def client_debug_path(self) -> typing.Optional[builtins.str]:
@@ -660,13 +588,13 @@ class VsphereProviderConfig:
     @builtins.property
     def persist_session(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Persist vSphere client sessions to disk.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere#persist_session VsphereProvider#persist_session}
         '''
         result = self._values.get("persist_session")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def rest_session_path(self) -> typing.Optional[builtins.str]:
@@ -728,3 +656,129 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__ee026a52613711b09c00984c1711ee0ea723e1281f3052e2fd4da2b6813e9712(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    password: builtins.str,
+    user: builtins.str,
+    alias: typing.Optional[builtins.str] = None,
+    allow_unverified_ssl: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    api_timeout: typing.Optional[jsii.Number] = None,
+    client_debug: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    client_debug_path: typing.Optional[builtins.str] = None,
+    client_debug_path_run: typing.Optional[builtins.str] = None,
+    persist_session: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    rest_session_path: typing.Optional[builtins.str] = None,
+    vcenter_server: typing.Optional[builtins.str] = None,
+    vim_keep_alive: typing.Optional[jsii.Number] = None,
+    vim_session_path: typing.Optional[builtins.str] = None,
+    vsphere_server: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__85a5c7404c22e2662c8f2b36e7bac7c3c330755af050b318ea3270269facd5fc(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__efa987cfc550d9bd2c5835330213c9fcee3a796902fa8c4e5c6a567d25c9382b(
+    value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1d49d1962d4c843bdc5b6559e73f4b084c4b70d0d6095e9df5cf25abb428444f(
+    value: typing.Optional[jsii.Number],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7cae6e0d733c5b071ac17da413a7c5bc493ce13b5b796b2c5e8af127cb3ac16e(
+    value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1d4a4c3885a74541897f23aaf27d7b316a33faafd025e441e73f82230789dc3b(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__017137ad0dd39052c7f9e0eda5e0706736e5179981fc2763a5440085c8ab25e8(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c8d6ab5398e3ff1d9b079ef3ac803090a563fc1150bf33ba54693aab2798cdbf(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__24e6a601113c7ec7d0d7ce3b407765402f397b51e33bf7c259d38d98cbb2650d(
+    value: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b27f34b61805c00af253b6df02b768883d159c15c46bcc8c546d3a561987131a(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d81d54af5728cb1a20ec1fda0589644e0697c48f1c2b8fc5ab341e53d5e19ca4(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bbbec703afa84abdf146fa976cc8187d65ff67fd45dc268b875e8372c4b39bf5(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2f66ec4c1c7d4a23480406c75d8cffe7c94f8b5f9980725dbd57f0b1d2843fd9(
+    value: typing.Optional[jsii.Number],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fdf3b73ca434e2bb2e75400348a4f079b7c72997eff4f0cd08ca18625dbb6c73(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1954f991ead072d7913c4b8fe881f938a0ec15394dc06da3984df4d4af2e8ce9(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5b3d3ddbf5e3b8ebcad247b5a75b14c872c731a5a99a03a31d3a90a237b8c26b(
+    *,
+    password: builtins.str,
+    user: builtins.str,
+    alias: typing.Optional[builtins.str] = None,
+    allow_unverified_ssl: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    api_timeout: typing.Optional[jsii.Number] = None,
+    client_debug: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    client_debug_path: typing.Optional[builtins.str] = None,
+    client_debug_path_run: typing.Optional[builtins.str] = None,
+    persist_session: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    rest_session_path: typing.Optional[builtins.str] = None,
+    vcenter_server: typing.Optional[builtins.str] = None,
+    vim_keep_alive: typing.Optional[jsii.Number] = None,
+    vim_session_path: typing.Optional[builtins.str] = None,
+    vsphere_server: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
