@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class VappEntity(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-vsphere.vappEntity.VappEntity",
 ):
@@ -30,7 +30,7 @@ class VappEntity(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         container_id: builtins.str,
@@ -43,14 +43,14 @@ class VappEntity(
         stop_action: typing.Optional[builtins.str] = None,
         stop_delay: typing.Optional[jsii.Number] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-        wait_for_guest: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        wait_for_guest: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/vsphere/r/vapp_entity vsphere_vapp_entity} Resource.
 
@@ -76,31 +76,7 @@ class VappEntity(
         :param provisioners: 
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id_: builtins.str,
-                *,
-                container_id: builtins.str,
-                target_id: builtins.str,
-                custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                id: typing.Optional[builtins.str] = None,
-                start_action: typing.Optional[builtins.str] = None,
-                start_delay: typing.Optional[jsii.Number] = None,
-                start_order: typing.Optional[jsii.Number] = None,
-                stop_action: typing.Optional[builtins.str] = None,
-                stop_delay: typing.Optional[jsii.Number] = None,
-                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-                wait_for_guest: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ac2cc21f17371f0815d4e8609d4e0a056a14e1d3176272af38fb155519e412c3)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = VappEntityConfig(
@@ -227,8 +203,8 @@ class VappEntity(
     @jsii.member(jsii_name="waitForGuestInput")
     def wait_for_guest_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "waitForGuestInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "waitForGuestInput"))
 
     @builtins.property
     @jsii.member(jsii_name="containerId")
@@ -238,9 +214,7 @@ class VappEntity(
     @container_id.setter
     def container_id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__663ae4c37f3cf45d66b04bd38a624ada2e6397a9d0673824578a6e0d8504a8c4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "containerId", value)
 
@@ -255,9 +229,7 @@ class VappEntity(
         value: typing.Mapping[builtins.str, builtins.str],
     ) -> None:
         if __debug__:
-            def stub(value: typing.Mapping[builtins.str, builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__23bd3e74ee5d3fd63dfca3f2e6dbc9802c5af284626409c56bb529ec1639e275)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "customAttributes", value)
 
@@ -269,9 +241,7 @@ class VappEntity(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b2f1ffe7e1be5805b7bab36e38aa9d76fea9c849dfdbbe5106fbe9bfa79280b5)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -283,9 +253,7 @@ class VappEntity(
     @start_action.setter
     def start_action(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__18235ff655e4582c2ca59de7b7a6327ee0a6e218265beafce452a203a573dcde)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "startAction", value)
 
@@ -297,9 +265,7 @@ class VappEntity(
     @start_delay.setter
     def start_delay(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__23c92a0fd4b406d2cb14531e2ae3e52f8097107e30149a677563c19b19ec15e6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "startDelay", value)
 
@@ -311,9 +277,7 @@ class VappEntity(
     @start_order.setter
     def start_order(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5cdd74937cf418eb810b1e8516b152374e09c1c6293c00cfd74b26078cbcc3bc)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "startOrder", value)
 
@@ -325,9 +289,7 @@ class VappEntity(
     @stop_action.setter
     def stop_action(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__59ff7b89ea05b3ee2b7cce22681727f0e949210dfc17cea9a92f783274f3fdae)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "stopAction", value)
 
@@ -339,9 +301,7 @@ class VappEntity(
     @stop_delay.setter
     def stop_delay(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3a1fc3c870b6e09c43138bce05a4de2f5a103ce0522cd152bc07c7210e6de119)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "stopDelay", value)
 
@@ -353,9 +313,7 @@ class VappEntity(
     @tags.setter
     def tags(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            def stub(value: typing.List[builtins.str]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b2d15dbd8bfb56db5fd868e5e9c04374c368c1ebd602c387b1a9e4128ac5d1a4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tags", value)
 
@@ -367,33 +325,31 @@ class VappEntity(
     @target_id.setter
     def target_id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9dbc7740ba56f947c9bd785643b6d4b0d2560ae1d44a0e38911acb010b7ee9a4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targetId", value)
 
     @builtins.property
     @jsii.member(jsii_name="waitForGuest")
-    def wait_for_guest(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "waitForGuest"))
+    def wait_for_guest(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "waitForGuest"))
 
     @wait_for_guest.setter
     def wait_for_guest(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5e6bc1618d974a3651dc34575b6541c4c9230f3c97a734a072380b61fcbef4c1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "waitForGuest", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-vsphere.vappEntity.VappEntityConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -415,17 +371,17 @@ class VappEntity(
         "wait_for_guest": "waitForGuest",
     },
 )
-class VappEntityConfig(cdktf.TerraformMetaArguments):
+class VappEntityConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         container_id: builtins.str,
         target_id: builtins.str,
         custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
@@ -436,7 +392,7 @@ class VappEntityConfig(cdktf.TerraformMetaArguments):
         stop_action: typing.Optional[builtins.str] = None,
         stop_delay: typing.Optional[jsii.Number] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-        wait_for_guest: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        wait_for_guest: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -459,31 +415,9 @@ class VappEntityConfig(cdktf.TerraformMetaArguments):
         :param wait_for_guest: Determines if the VM should be marked as being started when VMware Tools are ready instead of waiting for start_delay. This property has no effect for vApps. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/vapp_entity#wait_for_guest VappEntity#wait_for_guest}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            def stub(
-                *,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-                container_id: builtins.str,
-                target_id: builtins.str,
-                custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                id: typing.Optional[builtins.str] = None,
-                start_action: typing.Optional[builtins.str] = None,
-                start_delay: typing.Optional[jsii.Number] = None,
-                start_order: typing.Optional[jsii.Number] = None,
-                stop_action: typing.Optional[builtins.str] = None,
-                stop_delay: typing.Optional[jsii.Number] = None,
-                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
-                wait_for_guest: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__20861961d6d80b1bf7729680cacbf0a97abf934a3334d6b4495a15b1fcada92c)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -502,7 +436,7 @@ class VappEntityConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument stop_delay", value=stop_delay, expected_type=type_hints["stop_delay"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
             check_type(argname="argument wait_for_guest", value=wait_for_guest, expected_type=type_hints["wait_for_guest"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "container_id": container_id,
             "target_id": target_id,
         }
@@ -542,12 +476,12 @@ class VappEntityConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -558,46 +492,48 @@ class VappEntityConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def container_id(self) -> builtins.str:
@@ -703,7 +639,7 @@ class VappEntityConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def wait_for_guest(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Determines if the VM should be marked as being started when VMware Tools are ready instead of waiting for start_delay.
 
         This property has no effect for vApps.
@@ -711,7 +647,7 @@ class VappEntityConfig(cdktf.TerraformMetaArguments):
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/vsphere/r/vapp_entity#wait_for_guest VappEntity#wait_for_guest}
         '''
         result = self._values.get("wait_for_guest")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -731,3 +667,119 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__ac2cc21f17371f0815d4e8609d4e0a056a14e1d3176272af38fb155519e412c3(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    container_id: builtins.str,
+    target_id: builtins.str,
+    custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    start_action: typing.Optional[builtins.str] = None,
+    start_delay: typing.Optional[jsii.Number] = None,
+    start_order: typing.Optional[jsii.Number] = None,
+    stop_action: typing.Optional[builtins.str] = None,
+    stop_delay: typing.Optional[jsii.Number] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+    wait_for_guest: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__663ae4c37f3cf45d66b04bd38a624ada2e6397a9d0673824578a6e0d8504a8c4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__23bd3e74ee5d3fd63dfca3f2e6dbc9802c5af284626409c56bb529ec1639e275(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b2f1ffe7e1be5805b7bab36e38aa9d76fea9c849dfdbbe5106fbe9bfa79280b5(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__18235ff655e4582c2ca59de7b7a6327ee0a6e218265beafce452a203a573dcde(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__23c92a0fd4b406d2cb14531e2ae3e52f8097107e30149a677563c19b19ec15e6(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5cdd74937cf418eb810b1e8516b152374e09c1c6293c00cfd74b26078cbcc3bc(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__59ff7b89ea05b3ee2b7cce22681727f0e949210dfc17cea9a92f783274f3fdae(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3a1fc3c870b6e09c43138bce05a4de2f5a103ce0522cd152bc07c7210e6de119(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b2d15dbd8bfb56db5fd868e5e9c04374c368c1ebd602c387b1a9e4128ac5d1a4(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9dbc7740ba56f947c9bd785643b6d4b0d2560ae1d44a0e38911acb010b7ee9a4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5e6bc1618d974a3651dc34575b6541c4c9230f3c97a734a072380b61fcbef4c1(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__20861961d6d80b1bf7729680cacbf0a97abf934a3334d6b4495a15b1fcada92c(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    container_id: builtins.str,
+    target_id: builtins.str,
+    custom_attributes: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    start_action: typing.Optional[builtins.str] = None,
+    start_delay: typing.Optional[jsii.Number] = None,
+    start_order: typing.Optional[jsii.Number] = None,
+    stop_action: typing.Optional[builtins.str] = None,
+    stop_delay: typing.Optional[jsii.Number] = None,
+    tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+    wait_for_guest: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
